@@ -39,9 +39,21 @@ rstto_window_save_geometry_timer_destroy(gpointer user_data);
 static gboolean
 cb_rstto_main_window_configure_event (GtkWidget *widget, GdkEventConfigure *event);
 
+gboolean version = FALSE;
+
+static GOptionEntry entries[] =
+{
+    {	"version", 'v', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &version,
+		N_("Version information"),
+		NULL
+	},
+	{ NULL }
+};
+
 int main(int argc, char **argv)
 {
 
+	GError *cli_error = NULL;
     gint n;
 
     #ifdef ENABLE_NLS
@@ -50,7 +62,21 @@ int main(int argc, char **argv)
     textdomain (GETTEXT_PACKAGE);
     #endif
 
-    gtk_init(&argc, &argv);
+    if(!gtk_init_with_args(&argc, &argv, _(""), entries, PACKAGE, NULL))
+    {
+        if (cli_error != NULL)
+        {
+			g_print (_("%s: %s\nTry %s --help to see a full list of available command line options.\n"), PACKAGE, cli_error->message, PACKAGE_NAME);
+			g_error_free (cli_error);
+			return 1;
+        }
+    }
+
+	if(version)
+	{
+		g_print("%s\n", PACKAGE_STRING);
+		return 0;
+	}
 
     thunar_vfs_init();
 
@@ -66,11 +92,19 @@ int main(int argc, char **argv)
     gint window_width = xfce_rc_read_int_entry(xfce_rc, "LastWindowWidth", 400);
     gint window_height = xfce_rc_read_int_entry(xfce_rc, "LastWindowHeight", 300);
     gint slideshow_timeout = xfce_rc_read_int_entry(xfce_rc, "SlideShowTimeout", 5000);
+    gint max_cache = xfce_rc_read_int_entry(xfce_rc, "MaxImagesCacheSize", 1);
+    gboolean preload_during_slideshow = xfce_rc_read_bool_entry (xfce_rc, "PreloadDuringSlideShow", FALSE);
     
     GtkWidget *window = rstto_main_window_new();
     gtk_widget_ref(window);
 
     RsttoNavigator *navigator = rstto_main_window_get_navigator(RSTTO_MAIN_WINDOW(window));
+
+    navigator->preload = preload_during_slideshow;
+
+    rstto_main_window_set_max_cache_size(RSTTO_MAIN_WINDOW(window), max_cache);
+    rstto_main_window_set_slideshow_timeout(RSTTO_MAIN_WINDOW(window), (gdouble)slideshow_timeout);
+
     GtkRecentManager *recent_manager = rstto_main_window_get_recent_manager(RSTTO_MAIN_WINDOW(window));
     rstto_navigator_set_timeout(navigator, slideshow_timeout);
 
@@ -106,7 +140,6 @@ int main(int argc, char **argv)
                     const gchar *filename = g_dir_read_name(dir);
                     while (filename)
                     {
-                        rstto_navigator_set_is_album(navigator, FALSE);
                         gchar *path_name = g_strconcat(path_string,  "/", filename, NULL);
                         ThunarVfsPath *file_path = thunar_vfs_path_new(path_name, NULL);
                         if (file_path)
@@ -115,7 +148,7 @@ int main(int argc, char **argv)
                             gchar *file_media = thunar_vfs_mime_info_get_media(file_info->mime_info);
                             if(!strcmp(file_media, "image"))
                             {
-                                RsttoNavigatorEntry *entry = rstto_navigator_entry_new(file_info);
+                                RsttoNavigatorEntry *entry = rstto_navigator_entry_new(navigator, file_info);
                                 gint i = rstto_navigator_add (navigator, entry);
                                 if (!strcmp(path_name, argv[n]))
                                 {
@@ -135,7 +168,6 @@ int main(int argc, char **argv)
                 {
                     GDir *dir = g_dir_open(argv[n], 0, NULL);
                     const gchar *filename = g_dir_read_name(dir);
-                    rstto_navigator_set_is_album(navigator, TRUE);
                     while (filename)
                     {
                         gchar *path_name = g_strconcat(argv[n],  "/", filename, NULL);
@@ -146,7 +178,7 @@ int main(int argc, char **argv)
                             gchar *file_media = thunar_vfs_mime_info_get_media(file_info->mime_info);
                             if(!strcmp(file_media, "image"))
                             {
-                                RsttoNavigatorEntry *entry = rstto_navigator_entry_new(file_info);
+                                RsttoNavigatorEntry *entry = rstto_navigator_entry_new(navigator, file_info);
                                 rstto_navigator_add (navigator, entry);
                             }
                             g_free(file_media);
@@ -188,6 +220,7 @@ int main(int argc, char **argv)
 
     gtk_main();
     xfce_rc_write_bool_entry(xfce_rc, "ShowToolBar", rstto_main_window_get_show_toolbar(RSTTO_MAIN_WINDOW(window)));
+    xfce_rc_write_bool_entry(xfce_rc, "PreloadDuringSlideShow", navigator->preload);
     xfce_rc_write_bool_entry(xfce_rc, "ShowThumbnailViewer", rstto_main_window_get_show_thumbnail_viewer(RSTTO_MAIN_WINDOW(window)));
     switch (rstto_main_window_get_thumbnail_viewer_orientation(RSTTO_MAIN_WINDOW(window)))
     {
@@ -198,6 +231,8 @@ int main(int argc, char **argv)
             xfce_rc_write_entry(xfce_rc, "ThumbnailViewerOrientation", "horizontal");
             break;
     }
+    xfce_rc_write_int_entry(xfce_rc, "MaxImagesCacheSize", rstto_main_window_get_max_cache_size(RSTTO_MAIN_WINDOW(window)));
+    xfce_rc_write_int_entry(xfce_rc, "SlideShowTimeout", (gint)rstto_main_window_get_slideshow_timeout(RSTTO_MAIN_WINDOW(window)));
     xfce_rc_flush(xfce_rc);
     xfce_rc_close(xfce_rc);
     gtk_widget_unref(window);
