@@ -1001,31 +1001,37 @@ cb_rstto_main_window_preferences(GtkWidget *widget, RsttoMainWindow *window)
 {
     GtkWidget *dialog = xfce_titled_dialog_new_with_buttons(_("Image viewer Preferences"),
                                                     GTK_WINDOW(window),
-                                                    0,
+                                                    GTK_DIALOG_NO_SEPARATOR,
                                                     GTK_STOCK_CANCEL,
                                                     GTK_RESPONSE_CANCEL,
                                                     GTK_STOCK_OK,
                                                     GTK_RESPONSE_OK,
                                                     NULL);
     gtk_window_set_icon_name(GTK_WINDOW(dialog), "ristretto");
+    gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
 
     GtkWidget *notebook = gtk_notebook_new();
+    gtk_container_set_border_width(GTK_CONTAINER(notebook), 6);
 
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), notebook,  TRUE, TRUE, 0);
 
     GtkWidget *main_vbox = gtk_vbox_new(FALSE, 0);
-    GtkWidget *main_lbl = gtk_label_new(_("Behaviour"));
+    GtkWidget *main_lbl = gtk_label_new(_("Slideshow"));
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook), main_vbox, main_lbl);
 
-    GtkWidget *slideshow_frame = gtk_frame_new(_("Slideshow:"));
-    GtkWidget *preload_frame = gtk_frame_new(_("Preload:"));
-
     GtkWidget *slideshow_vbox = gtk_vbox_new(FALSE, 0);
+    GtkWidget *slideshow_frame = xfce_create_framebox_with_content (_("Timeout"), slideshow_vbox);
+
+    GtkWidget *preload_vbox = gtk_vbox_new(FALSE, 0);
+    GtkWidget *preload_frame = xfce_create_framebox_with_content (_("Preload"), preload_vbox);
+
+    gtk_container_set_border_width (GTK_CONTAINER (slideshow_frame), 8);
+    gtk_container_set_border_width (GTK_CONTAINER (preload_frame), 8);
+
     GtkWidget *slideshow_lbl = gtk_label_new(_("The time individual images are displayed during a slideshow\n(in seconds)"));
     GtkWidget *slideshow_hscale = gtk_hscale_new_with_range(1, 60, 1);
 
 
-    GtkWidget *preload_vbox = gtk_vbox_new(FALSE, 0);
     GtkWidget *preload_lbl = gtk_label_new(_("Preload images during slideshow\n(uses more memory)"));
     GtkWidget *preload_check = gtk_check_button_new_with_mnemonic(_("_Preload images"));
 
@@ -1045,9 +1051,6 @@ cb_rstto_main_window_preferences(GtkWidget *widget, RsttoMainWindow *window)
     gtk_box_pack_start(GTK_BOX(preload_vbox), preload_lbl, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(preload_vbox), preload_check, FALSE, TRUE, 0);
 
-    gtk_container_add(GTK_CONTAINER(slideshow_frame), slideshow_vbox);
-    gtk_container_add(GTK_CONTAINER(preload_frame), preload_vbox);
-
     gtk_box_pack_start(GTK_BOX(main_vbox), slideshow_frame, FALSE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(main_vbox), preload_frame, FALSE, TRUE, 0);
 
