@@ -24,9 +24,6 @@
 #include "navigator.h"
 #include "picture_viewer.h"
 
-#ifndef RSTTO_PICTURE_VIEWER_DRAG_MOTION_TIMEOUT
-#define RSTTO_PICTURE_VIEWER_DRAG_MOTION_TIMEOUT 160
-#endif
 
 struct _RsttoPictureViewerPriv
 {
@@ -45,13 +42,11 @@ struct _RsttoPictureViewerPriv
         gdouble current_y;
         gint h_val;
         gint v_val;
-        gint32 time;
-        gint idle_id;
     } motion;
     struct
     {
         gint idle_id;
-    } zoom;
+    } refresh;
     GtkMenu          *menu;
 };
 
@@ -63,7 +58,7 @@ static void
 rstto_picture_viewer_destroy(GtkObject *object);
 
 static gboolean 
-cb_rstto_picture_viewer_queued_redraw (RsttoPictureViewer *viewer);
+cb_rstto_picture_viewer_queued_repaint(RsttoPictureViewer *viewer);
 
 static void
 rstto_picture_viewer_size_request(GtkWidget *, GtkRequisition *);
@@ -393,76 +388,11 @@ rstto_picture_viewer_set_scroll_adjustments(RsttoPictureViewer *viewer, GtkAdjus
 static void
 cb_rstto_picture_viewer_value_changed(GtkAdjustment *adjustment, RsttoPictureViewer *viewer)
 {
-    gdouble scale = 1.0;
-    gdouble width = 1.0;
-    gdouble height = 1.0;
-    GtkWidget *widget = GTK_WIDGET(viewer);
-    RsttoNavigatorEntry *entry = rstto_navigator_get_file(viewer->priv->navigator);
-    if (entry)
+    if (viewer->priv->refresh.idle_id > 0)
     {
-        scale = rstto_navigator_entry_get_scale(entry);
-        width = (gdouble)gdk_pixbuf_get_width(viewer->priv->src_pixbuf);
-        height = (gdouble)gdk_pixbuf_get_height(viewer->priv->src_pixbuf);
+        g_source_remove(viewer->priv->refresh.idle_id);
     }
-    if (viewer->priv->src_pixbuf == NULL)
-    {
-        return;
-    }
-    GdkPixbuf *tmp_pixbuf = NULL;
-    if (viewer->vadjustment && viewer->hadjustment)
-    {
-        if ((width > widget->allocation.width) || (height > widget->allocation.height))
-        {
-            tmp_pixbuf = gdk_pixbuf_new_subpixbuf(viewer->priv->src_pixbuf,
-                                              viewer->hadjustment->value / scale >= 0?
-                                                viewer->hadjustment->value / scale : 0,
-                                              viewer->vadjustment->value / scale >= 0?
-                                                viewer->vadjustment->value / scale : 0,
-                                              ((widget->allocation.width/scale)) < width?
-                                                widget->allocation.width/scale:width,
-                                              ((widget->allocation.height/scale))< height?
-                                                widget->allocation.height/scale:height);
-        }
-        else
-        {
-            tmp_pixbuf = viewer->priv->src_pixbuf;
-            g_object_ref(tmp_pixbuf);
-        }
-    }
-
-    if(viewer->priv->dst_pixbuf)
-    {
-        g_object_unref(viewer->priv->dst_pixbuf);
-        viewer->priv->dst_pixbuf = NULL;
-    }
-
-    if(tmp_pixbuf)
-    {
-        gint dst_width = gdk_pixbuf_get_width(tmp_pixbuf)*scale;
-        gint dst_height = gdk_pixbuf_get_height(tmp_pixbuf)*scale;
-        if (scale < 1.0)
-        {
-            viewer->priv->dst_pixbuf = gdk_pixbuf_scale_simple(tmp_pixbuf,
-                                dst_width>0?dst_width:1,
-                                dst_height>0?dst_height:1,
-                                GDK_INTERP_BILINEAR);
-        }
-        if (scale > 1.0)
-        {
-            viewer->priv->dst_pixbuf = gdk_pixbuf_scale_simple(tmp_pixbuf,
-                                dst_width>0?dst_width:1,
-                                dst_height>0?dst_height:1,
-                                GDK_INTERP_NEAREST);
-        }
-        if (scale == 1.0)
-        {
-            viewer->priv->dst_pixbuf = tmp_pixbuf;
-            g_object_ref(viewer->priv->dst_pixbuf);
-        }
-        g_object_unref(tmp_pixbuf);
-        tmp_pixbuf = NULL;
-    }
-    rstto_picture_viewer_paint(widget);
+    viewer->priv->refresh.idle_id = g_idle_add((GSourceFunc)cb_rstto_picture_viewer_queued_repaint, viewer);
 }
 
 GtkWidget *
@@ -668,13 +598,11 @@ rstto_picture_viewer_refresh(RsttoPictureViewer *viewer)
             GdkPixbuf *tmp_pixbuf = NULL;
             if (viewer->vadjustment && viewer->hadjustment)
             {
-                if (scale < 1.0)
+                if (1.0)
                 {
                     tmp_pixbuf = gdk_pixbuf_new_subpixbuf(viewer->priv->src_pixbuf,
-                                                      viewer->hadjustment->value / scale >= 0?
-                                                        viewer->hadjustment->value / scale : 0,
-                                                      viewer->vadjustment->value / scale >= 0?
-                                                        viewer->vadjustment->value / scale : 0,
+                                                      (gint)(viewer->hadjustment->value / scale), 
+                                                      viewer->vadjustment->value / scale,
                                                       ((widget->allocation.width/scale)) < width?
                                                         widget->allocation.width/scale:width,
                                                       ((widget->allocation.height/scale))< height?
@@ -771,19 +699,37 @@ cb_rstto_picture_viewer_scroll_event (RsttoPictureViewer *viewer, GdkEventScroll
         case GDK_SCROLL_LEFT:
             if (scale <= 0.05)
                 return;
-            if (viewer->priv->motion.idle_id > 0)
+            if (viewer->priv->refresh.idle_id > 0)
             {
-                g_source_remove(viewer->priv->motion.idle_id);
+                g_source_remove(viewer->priv->refresh.idle_id);
             }
+            rstto_navigator_entry_set_scale(entry, scale / 1.1);
+            rstto_navigator_entry_set_fit_to_screen (entry, FALSE);
+
+            viewer->vadjustment->value = ((viewer->vadjustment->value + event->y) / 1.1) - event->y;
+            viewer->hadjustment->value = ((viewer->hadjustment->value + event->x) / 1.1) - event->x;
+
+            viewer->priv->refresh.idle_id = g_idle_add((GSourceFunc)cb_rstto_picture_viewer_queued_repaint, viewer);
             break;
         case GDK_SCROLL_DOWN:
         case GDK_SCROLL_RIGHT:
             if (scale >= 16)
                 return;
-            if (viewer->priv->motion.idle_id > 0)
+            if (viewer->priv->refresh.idle_id > 0)
             {
-                g_source_remove(viewer->priv->motion.idle_id);
+                g_source_remove(viewer->priv->refresh.idle_id);
             }
+            rstto_navigator_entry_set_scale(entry, scale * 1.1);
+            rstto_navigator_entry_set_fit_to_screen (entry, FALSE);
+
+
+            viewer->vadjustment->value = ((viewer->vadjustment->value + event->y) * 1.1) - event->y;
+            viewer->hadjustment->value = ((viewer->hadjustment->value + event->x) * 1.1) - event->x;
+
+            gtk_adjustment_value_changed(viewer->hadjustment);
+            gtk_adjustment_value_changed(viewer->vadjustment);
+
+            viewer->priv->refresh.idle_id = g_idle_add((GSourceFunc)cb_rstto_picture_viewer_queued_repaint, viewer);
             break;
     }
 }
@@ -795,57 +741,56 @@ cb_rstto_picture_viewer_motion_notify_event (RsttoPictureViewer *viewer,
 {
     if (event->state & GDK_BUTTON1_MASK)
     {
-        if (viewer->priv->motion.time == 0)
-            viewer->priv->motion.time = gtk_get_current_event_time();
-
         viewer->priv->motion.current_x = event->x;
         viewer->priv->motion.current_y = event->y;
 
-        if (viewer->priv->motion.idle_id > 0)
+        if (viewer->priv->refresh.idle_id > 0)
         {
-            g_source_remove(viewer->priv->motion.idle_id);
+            g_source_remove(viewer->priv->refresh.idle_id);
+            viewer->priv->refresh.idle_id = 0;
         }
 
-        viewer->priv->motion.idle_id = g_idle_add((GSourceFunc)cb_rstto_picture_viewer_queued_redraw, viewer);
+        if (viewer->priv->motion.x != viewer->priv->motion.current_x)
+        {
+            gint val = viewer->hadjustment->value;
+            viewer->hadjustment->value = viewer->priv->motion.h_val + (viewer->priv->motion.x - viewer->priv->motion.current_x);
+            if((viewer->hadjustment->value + viewer->hadjustment->page_size) > viewer->hadjustment->upper)
+            {
+                viewer->hadjustment->value = viewer->hadjustment->upper - viewer->hadjustment->page_size;
+            }
+            if((viewer->hadjustment->value) < viewer->hadjustment->lower)
+            {
+                viewer->hadjustment->value = viewer->hadjustment->lower;
+            }
+            if (val != viewer->hadjustment->value)
+                gtk_adjustment_value_changed(viewer->hadjustment);
+        }
+
+        if (viewer->priv->motion.y != viewer->priv->motion.current_y)
+        {
+            gint val = viewer->vadjustment->value;
+            viewer->vadjustment->value = viewer->priv->motion.v_val + (viewer->priv->motion.y - viewer->priv->motion.current_y);
+            if((viewer->vadjustment->value + viewer->vadjustment->page_size) > viewer->vadjustment->upper)
+            {
+                viewer->vadjustment->value = viewer->vadjustment->upper - viewer->vadjustment->page_size;
+            }
+            if((viewer->vadjustment->value) < viewer->vadjustment->lower)
+            {
+                viewer->vadjustment->value = viewer->vadjustment->lower;
+            }
+            if (val != viewer->vadjustment->value)
+                gtk_adjustment_value_changed(viewer->vadjustment);
+        }
     }
     return FALSE;
 }
 
 static gboolean 
-cb_rstto_picture_viewer_queued_redraw (RsttoPictureViewer *viewer)
+cb_rstto_picture_viewer_queued_repaint(RsttoPictureViewer *viewer)
 {
-    if (viewer->priv->motion.x != viewer->priv->motion.current_x)
-    {
-        gint val = viewer->hadjustment->value;
-        viewer->hadjustment->value = viewer->priv->motion.h_val + (viewer->priv->motion.x - viewer->priv->motion.current_x);
-        if((viewer->hadjustment->value + viewer->hadjustment->page_size) > viewer->hadjustment->upper)
-        {
-            viewer->hadjustment->value = viewer->hadjustment->upper - viewer->hadjustment->page_size;
-        }
-        if((viewer->hadjustment->value) < viewer->hadjustment->lower)
-        {
-            viewer->hadjustment->value = viewer->hadjustment->lower;
-        }
-        if (val != viewer->hadjustment->value)
-            gtk_adjustment_value_changed(viewer->hadjustment);
-    }
-
-    if (viewer->priv->motion.y != viewer->priv->motion.current_y)
-    {
-        gint val = viewer->vadjustment->value;
-        viewer->vadjustment->value = viewer->priv->motion.v_val + (viewer->priv->motion.y - viewer->priv->motion.current_y);
-        if((viewer->vadjustment->value + viewer->vadjustment->page_size) > viewer->vadjustment->upper)
-        {
-            viewer->vadjustment->value = viewer->vadjustment->upper - viewer->vadjustment->page_size;
-        }
-        if((viewer->vadjustment->value) < viewer->vadjustment->lower)
-        {
-            viewer->vadjustment->value = viewer->vadjustment->lower;
-        }
-        if (val != viewer->vadjustment->value)
-            gtk_adjustment_value_changed(viewer->vadjustment);
-    }
-    viewer->priv->motion.idle_id = -1;
+    rstto_picture_viewer_refresh(viewer);
+    rstto_picture_viewer_paint(GTK_WIDGET(viewer));
+    viewer->priv->refresh.idle_id = -1;
     return FALSE;
 }
 
